#!/usr/bin/env python3

import json
import os
from pathlib import Path

def generate_workspace_file(workspace_path):
    """Generate VS Code workspace file for a multi-package project."""
    workspace_name = os.path.basename(workspace_path)
    
    src_path = os.path.join(workspace_path, "src")
    if not os.path.exists(src_path):
        raise FileNotFoundError(f"src directory not found in {workspace_path}")

    packages = sorted([d for d in os.listdir(src_path) 
                      if os.path.isdir(os.path.join(src_path, d))])

    workspace_config = {
        "folders": [
            {
                "name": f"📦 {package}",
                "path": f"src/{package}"
            }
            for package in packages
        ],
        "launch": {
            "version": "0.2.0",
            "configurations": [
                {
                    "name": "Python Debugger: Remote Attach Service Tests",
                    "type": "debugpy",
                    "request": "attach",
                    "connect": {
                        "host": "localhost",
                        "port": 5678
                    },
                    "justMyCode": False,
                    "pathMappings": [
                        {
                            "localRoot": f"${{workspaceFolder:📦 {package}}}",
                            "remoteRoot": f"src/{package}"
                        }
                        for package in packages
                    ]
                }
            ]
        }
    }

    output_file = os.path.join(workspace_path, f"{workspace_name}.code-workspace")
    with open(output_file, 'w', encoding='utf-8') as f:
        json.dump(workspace_config, f, indent=4, ensure_ascii=False)

    print(f"Generated workspace file: {output_file}")
    print("\n📝 To use remote debugging, add this to your Python code:")
    print('import debugpy; debugpy.listen(5678);print("🛑 Waiting for debugger to attach on port 5678...");debugpy.wait_for_client()')
    
    return output_file


#!/usr/bin/env python3

from setuptools import setup, find_packages

setup(
    name="vscode_workspace_config_generator",
    version="1.1.2",
    description="Generate VS Code workspace files for multi-package projects",
    author="Your Name",
    author_email="your.email@example.com",
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'generate-vscode-workspace-config=workspace_generator.cli:main',
        ],
    },
    python_requires='>=3.6',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)


#!/usr/bin/env python3

import os
import sys
from .generator import generate_workspace_file

def find_workspace_root():
    """Find workspace root by looking for src directory."""
    current_dir = os.getcwd()
    while current_dir != "/":
        if os.path.isdir(os.path.join(current_dir, "src")):
            return current_dir
        current_dir = os.path.dirname(current_dir)
    return None

def main():
    """Main CLI entry point."""
    if len(sys.argv) > 1:
        workspace_path = sys.argv[1]
    else:
        workspace_path = find_workspace_root()
        if not workspace_path:
            print("Error: Could not find workspace root (directory containing 'src' folder)")
            sys.exit(1)

    try:
        generate_workspace_file(workspace_path)
    except FileNotFoundError as e:
        print(f"Error: {e}")
        sys.exit(1)

if __name__ == "__main__":
    main()